@@ -14,7 +14,10 @@ use Sub::Quote ();
 
 # RECOMMEND PREREQ: Ref::Util::XS
 
-our $VERSION = 'v0.1.2';
+our $VERSION = 'v0.1.3';
+
+# The names of all methods installed by this module.
+my %MINE;
 
 
 sub add_columns {
@@ -54,12 +57,22 @@ sub add_columns {
 
             my $method = "${class}::${handler}";
 
+            # Keep track of what we've installed, and don't complain about
+            # being asked to reinstall it. This is needed when using
+            # DBIx::Class::Schema::Loader. In theory we should check whether
+            # the current method is the one we installed, and throw anyway if
+            # it isn't, but this seems adequate.
             DBIx::Class::Exception->throw("${method} is already defined")
-              if $self->can($method);
+              if $self->can($method) && !$MINE{$method};
 
-            Sub::Quote::quote_sub $method,
-              qq{ my \$val = \$_[0]->get_column("${col}"); }
-              . qq{ defined(\$val) && \$val eq "${value}" };
+            my $code =
+              $info->{is_nullable}
+              ? qq{ my \$val = \$_[0]->get_column("${col}"); }
+              . qq{ defined(\$val) && \$val eq "${value}" }
+              : qq{ \$_[0]->get_column("${col}") eq "${value}" };
+
+            $MINE{$method} = 1;
+            Sub::Quote::quote_sub $method, $code;
 
         }
 
@@ -83,7 +96,7 @@ DBIx::Class::Helper::Row::Enumeration - Add methods for emum values
 
 =head1 VERSION
 
-version v0.1.2
+version v0.1.3
 
 =head1 SYNOPSIS
 
@@ -209,6 +222,12 @@ Robert Rothenberg <rrwo@cpan.org>
 The initial development of this module was sponsored by Science Photo
 Library L<https://www.sciencephoto.com>.
 
+=head1 CONTRIBUTOR
+
+=for stopwords Aaron Crane
+
+Aaron Crane <arc@cpan.org>
+
 =head1 COPYRIGHT AND LICENSE
 
 This software is Copyright (c) 2018 by Robert Rothenberg.
